LocalizationStrings class sealed

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEnglish() → String
returns the unions label in english
toGerman() → String
returns the unions label in german
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

applyLanguageCode(LocalizationStrings localization, String languageCode) → String
based on the languageCode the localization is returned in the corresponding language