LocalizationStringsWayfarers class final

Inheritance

Constructors

LocalizationStringsWayfarers()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEnglish() → String
returns the unions label in english
inherited
toGerman() → String
returns the unions label in german
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited